Struct style::context::CascadeInputs
[−]
[src]
pub struct CascadeInputs {
pub rules: Option<StrongRuleNode>,
pub visited_rules: Option<StrongRuleNode>,
}The structure holds various intermediate inputs that are eventually used by by the cascade.
The matching and cascading process stores them in this format temporarily
within the CurrentElementInfo. At the end of the cascade, they are folded
down into the main ComputedValues to reduce memory usage per element while
still remaining accessible.
Fields
rules: Option<StrongRuleNode>
The rule node representing the ordered list of rules matched for this node.
visited_rules: Option<StrongRuleNode>
The rule node representing the ordered list of rules matched for this node if visited, only computed if there's a relevant link for this element. A element's "relevant link" is the element being matched if it is a link or the nearest ancestor link.
Methods
impl CascadeInputs[src]
pub fn new_from_style(style: &ComputedValues) -> Self[src]
Construct inputs from previous cascade results, if any.