Struct style::context::ElementCascadeInputs
[−]
[src]
pub struct ElementCascadeInputs {
pub primary: CascadeInputs,
pub pseudos: EagerPseudoCascadeInputs,
}The cascade inputs associated with a node, including those for any pseudo-elements.
The matching and cascading process stores them in this format temporarily
within the CurrentElementInfo. At the end of the cascade, they are folded
down into the main ComputedValues to reduce memory usage per element while
still remaining accessible.
Fields
primary: CascadeInputs
The element's cascade inputs.
pseudos: EagerPseudoCascadeInputs
A list of the inputs for the element's eagerly-cascaded pseudo-elements.
Methods
impl ElementCascadeInputs[src]
pub fn new_from_element_data(data: &ElementData) -> Self[src]
Construct inputs from previous cascade results, if any.